@@ -5,18 +5,16 @@
 // SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
-//
-// UNSUPPORTED: libcpp-has-no-threads
 
 // <atomic>
 
-// template <class Integral>
-//     Integral
-//     atomic_fetch_xor(volatile atomic<Integral>* obj, Integral op);
+// template<class T>
+//     T
+//     atomic_fetch_xor(volatile atomic<T>*, atomic<T>::value_type) noexcept;
 //
-// template <class Integral>
-//     Integral
-//     atomic_fetch_xor(atomic<Integral>* obj, Integral op);
+// template<class T>
+//     T
+//     atomic_fetch_xor(atomic<T>*, atomic<T>::value_type) noexcept;
 
 #include <atomic>
 #include <type_traits>
@@ -33,12 +31,16 @@ struct TestFn {
         A t(T(1));
         assert(std::atomic_fetch_xor(&t, T(2)) == T(1));
         assert(t == T(3));
+
+        ASSERT_NOEXCEPT(std::atomic_fetch_xor(&t, T(2)));
     }
     {
         typedef std::atomic<T> A;
         volatile A t(T(3));
         assert(std::atomic_fetch_xor(&t, T(2)) == T(3));
         assert(t == T(1));
+
+        ASSERT_NOEXCEPT(std::atomic_fetch_xor(&t, T(2)));
     }
   }
 };
