@@ -13,6 +13,7 @@
 
 #include <forward_list>
 #include <cassert>
+#include <iterator>
 
 #include "test_macros.h"
 #include "test_allocator.h"
@@ -30,19 +31,19 @@ int main(int, char**)
         C c2(std::begin(t2), std::end(t2), A(1, 2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 3);
-        assert(*next(c1.begin(), 0) == 10);
-        assert(*next(c1.begin(), 1) == 11);
-        assert(*next(c1.begin(), 2) == 12);
+        assert(std::distance(c1.begin(), c1.end()) == 3);
+        assert(*std::next(c1.begin(), 0) == 10);
+        assert(*std::next(c1.begin(), 1) == 11);
+        assert(*std::next(c1.begin(), 2) == 12);
         assert(c1.get_allocator().get_id() == 1);
 
-        assert(distance(c2.begin(), c2.end()) == 6);
-        assert(*next(c2.begin(), 0) == 0);
-        assert(*next(c2.begin(), 1) == 1);
-        assert(*next(c2.begin(), 2) == 2);
-        assert(*next(c2.begin(), 3) == 3);
-        assert(*next(c2.begin(), 4) == 4);
-        assert(*next(c2.begin(), 5) == 5);
+        assert(std::distance(c2.begin(), c2.end()) == 6);
+        assert(*std::next(c2.begin(), 0) == 0);
+        assert(*std::next(c2.begin(), 1) == 1);
+        assert(*std::next(c2.begin(), 2) == 2);
+        assert(*std::next(c2.begin(), 3) == 3);
+        assert(*std::next(c2.begin(), 4) == 4);
+        assert(*std::next(c2.begin(), 5) == 5);
         assert(c2.get_allocator().get_id() == 2);
     }
     {
@@ -54,16 +55,16 @@ int main(int, char**)
         C c2(A(1, 2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 0);
+        assert(std::distance(c1.begin(), c1.end()) == 0);
         assert(c1.get_allocator().get_id() == 1);
 
-        assert(distance(c2.begin(), c2.end()) == 6);
-        assert(*next(c2.begin(), 0) == 0);
-        assert(*next(c2.begin(), 1) == 1);
-        assert(*next(c2.begin(), 2) == 2);
-        assert(*next(c2.begin(), 3) == 3);
-        assert(*next(c2.begin(), 4) == 4);
-        assert(*next(c2.begin(), 5) == 5);
+        assert(std::distance(c2.begin(), c2.end()) == 6);
+        assert(*std::next(c2.begin(), 0) == 0);
+        assert(*std::next(c2.begin(), 1) == 1);
+        assert(*std::next(c2.begin(), 2) == 2);
+        assert(*std::next(c2.begin(), 3) == 3);
+        assert(*std::next(c2.begin(), 4) == 4);
+        assert(*std::next(c2.begin(), 5) == 5);
         assert(c2.get_allocator().get_id() == 2);
     }
     {
@@ -75,13 +76,13 @@ int main(int, char**)
         C c2(std::begin(t2), std::end(t2), A(1, 2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 3);
-        assert(*next(c1.begin(), 0) == 10);
-        assert(*next(c1.begin(), 1) == 11);
-        assert(*next(c1.begin(), 2) == 12);
+        assert(std::distance(c1.begin(), c1.end()) == 3);
+        assert(*std::next(c1.begin(), 0) == 10);
+        assert(*std::next(c1.begin(), 1) == 11);
+        assert(*std::next(c1.begin(), 2) == 12);
         assert(c1.get_allocator().get_id() == 1);
 
-        assert(distance(c2.begin(), c2.end()) == 0);
+        assert(std::distance(c2.begin(), c2.end()) == 0);
         assert(c2.get_allocator().get_id() == 2);
     }
     {
@@ -92,10 +93,10 @@ int main(int, char**)
         C c2(A(1, 2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 0);
+        assert(std::distance(c1.begin(), c1.end()) == 0);
         assert(c1.get_allocator().get_id() == 1);
 
-        assert(distance(c2.begin(), c2.end()) == 0);
+        assert(std::distance(c2.begin(), c2.end()) == 0);
         assert(c2.get_allocator().get_id() == 2);
     }
 
@@ -109,19 +110,19 @@ int main(int, char**)
         C c2(std::begin(t2), std::end(t2), A(2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 3);
-        assert(*next(c1.begin(), 0) == 10);
-        assert(*next(c1.begin(), 1) == 11);
-        assert(*next(c1.begin(), 2) == 12);
+        assert(std::distance(c1.begin(), c1.end()) == 3);
+        assert(*std::next(c1.begin(), 0) == 10);
+        assert(*std::next(c1.begin(), 1) == 11);
+        assert(*std::next(c1.begin(), 2) == 12);
         assert(c1.get_allocator() == A(2));
 
-        assert(distance(c2.begin(), c2.end()) == 6);
-        assert(*next(c2.begin(), 0) == 0);
-        assert(*next(c2.begin(), 1) == 1);
-        assert(*next(c2.begin(), 2) == 2);
-        assert(*next(c2.begin(), 3) == 3);
-        assert(*next(c2.begin(), 4) == 4);
-        assert(*next(c2.begin(), 5) == 5);
+        assert(std::distance(c2.begin(), c2.end()) == 6);
+        assert(*std::next(c2.begin(), 0) == 0);
+        assert(*std::next(c2.begin(), 1) == 1);
+        assert(*std::next(c2.begin(), 2) == 2);
+        assert(*std::next(c2.begin(), 3) == 3);
+        assert(*std::next(c2.begin(), 4) == 4);
+        assert(*std::next(c2.begin(), 5) == 5);
         assert(c2.get_allocator() == A(1));
     }
     {
@@ -133,16 +134,16 @@ int main(int, char**)
         C c2(A(2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 0);
+        assert(std::distance(c1.begin(), c1.end()) == 0);
         assert(c1.get_allocator() == A(2));
 
-        assert(distance(c2.begin(), c2.end()) == 6);
-        assert(*next(c2.begin(), 0) == 0);
-        assert(*next(c2.begin(), 1) == 1);
-        assert(*next(c2.begin(), 2) == 2);
-        assert(*next(c2.begin(), 3) == 3);
-        assert(*next(c2.begin(), 4) == 4);
-        assert(*next(c2.begin(), 5) == 5);
+        assert(std::distance(c2.begin(), c2.end()) == 6);
+        assert(*std::next(c2.begin(), 0) == 0);
+        assert(*std::next(c2.begin(), 1) == 1);
+        assert(*std::next(c2.begin(), 2) == 2);
+        assert(*std::next(c2.begin(), 3) == 3);
+        assert(*std::next(c2.begin(), 4) == 4);
+        assert(*std::next(c2.begin(), 5) == 5);
         assert(c2.get_allocator() == A(1));
     }
     {
@@ -154,13 +155,13 @@ int main(int, char**)
         C c2(std::begin(t2), std::end(t2), A(2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 3);
-        assert(*next(c1.begin(), 0) == 10);
-        assert(*next(c1.begin(), 1) == 11);
-        assert(*next(c1.begin(), 2) == 12);
+        assert(std::distance(c1.begin(), c1.end()) == 3);
+        assert(*std::next(c1.begin(), 0) == 10);
+        assert(*std::next(c1.begin(), 1) == 11);
+        assert(*std::next(c1.begin(), 2) == 12);
         assert(c1.get_allocator() == A(2));
 
-        assert(distance(c2.begin(), c2.end()) == 0);
+        assert(std::distance(c2.begin(), c2.end()) == 0);
         assert(c2.get_allocator() == A(1));
     }
     {
@@ -171,10 +172,10 @@ int main(int, char**)
         C c2(A(2));
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 0);
+        assert(std::distance(c1.begin(), c1.end()) == 0);
         assert(c1.get_allocator() == A(2));
 
-        assert(distance(c2.begin(), c2.end()) == 0);
+        assert(std::distance(c2.begin(), c2.end()) == 0);
         assert(c2.get_allocator() == A(1));
     }
 #if TEST_STD_VER >= 11
@@ -188,19 +189,19 @@ int main(int, char**)
         C c2(std::begin(t2), std::end(t2), A());
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 3);
-        assert(*next(c1.begin(), 0) == 10);
-        assert(*next(c1.begin(), 1) == 11);
-        assert(*next(c1.begin(), 2) == 12);
+        assert(std::distance(c1.begin(), c1.end()) == 3);
+        assert(*std::next(c1.begin(), 0) == 10);
+        assert(*std::next(c1.begin(), 1) == 11);
+        assert(*std::next(c1.begin(), 2) == 12);
         assert(c1.get_allocator() == A());
 
-        assert(distance(c2.begin(), c2.end()) == 6);
-        assert(*next(c2.begin(), 0) == 0);
-        assert(*next(c2.begin(), 1) == 1);
-        assert(*next(c2.begin(), 2) == 2);
-        assert(*next(c2.begin(), 3) == 3);
-        assert(*next(c2.begin(), 4) == 4);
-        assert(*next(c2.begin(), 5) == 5);
+        assert(std::distance(c2.begin(), c2.end()) == 6);
+        assert(*std::next(c2.begin(), 0) == 0);
+        assert(*std::next(c2.begin(), 1) == 1);
+        assert(*std::next(c2.begin(), 2) == 2);
+        assert(*std::next(c2.begin(), 3) == 3);
+        assert(*std::next(c2.begin(), 4) == 4);
+        assert(*std::next(c2.begin(), 5) == 5);
         assert(c2.get_allocator() == A());
     }
     {
@@ -212,16 +213,16 @@ int main(int, char**)
         C c2(A{});
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 0);
+        assert(std::distance(c1.begin(), c1.end()) == 0);
         assert(c1.get_allocator() == A());
 
-        assert(distance(c2.begin(), c2.end()) == 6);
-        assert(*next(c2.begin(), 0) == 0);
-        assert(*next(c2.begin(), 1) == 1);
-        assert(*next(c2.begin(), 2) == 2);
-        assert(*next(c2.begin(), 3) == 3);
-        assert(*next(c2.begin(), 4) == 4);
-        assert(*next(c2.begin(), 5) == 5);
+        assert(std::distance(c2.begin(), c2.end()) == 6);
+        assert(*std::next(c2.begin(), 0) == 0);
+        assert(*std::next(c2.begin(), 1) == 1);
+        assert(*std::next(c2.begin(), 2) == 2);
+        assert(*std::next(c2.begin(), 3) == 3);
+        assert(*std::next(c2.begin(), 4) == 4);
+        assert(*std::next(c2.begin(), 5) == 5);
         assert(c2.get_allocator() == A());
     }
     {
@@ -233,13 +234,13 @@ int main(int, char**)
         C c2(std::begin(t2), std::end(t2), A());
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 3);
-        assert(*next(c1.begin(), 0) == 10);
-        assert(*next(c1.begin(), 1) == 11);
-        assert(*next(c1.begin(), 2) == 12);
+        assert(std::distance(c1.begin(), c1.end()) == 3);
+        assert(*std::next(c1.begin(), 0) == 10);
+        assert(*std::next(c1.begin(), 1) == 11);
+        assert(*std::next(c1.begin(), 2) == 12);
         assert(c1.get_allocator() == A());
 
-        assert(distance(c2.begin(), c2.end()) == 0);
+        assert(std::distance(c2.begin(), c2.end()) == 0);
         assert(c2.get_allocator() == A());
     }
     {
@@ -250,10 +251,10 @@ int main(int, char**)
         C c2(A{});
         c1.swap(c2);
 
-        assert(distance(c1.begin(), c1.end()) == 0);
+        assert(std::distance(c1.begin(), c1.end()) == 0);
         assert(c1.get_allocator() == A());
 
-        assert(distance(c2.begin(), c2.end()) == 0);
+        assert(std::distance(c2.begin(), c2.end()) == 0);
         assert(c2.get_allocator() == A());
     }
 #endif
