@@ -1,10 +1,8 @@
-// -*- C++ -*-
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
@@ -12,6 +10,8 @@
 
 #include <errno.h>
 
+#include "test_macros.h"
+
 #ifndef EDOM
 #error EDOM not defined
 #endif
@@ -28,6 +28,8 @@
 #error errno not defined
 #endif
 
-int main()
+int main(int, char**)
 {
+
+  return 0;
 }
