@@ -1,14 +1,17 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// REQUIRES: c++experimental
-// UNSUPPORTED: c++98, c++03
+// UNSUPPORTED: c++03
+
+// Aligned allocation is required by std::experimental::pmr, but it was not provided
+// before macosx10.13 and as a result we get linker errors when deploying to older than
+// macosx10.13.
+// XFAIL: use_system_cxx_lib && target={{.+}}-apple-macosx10.{{9|10|11|12}}
 
 // <experimental/memory_resource>
 
@@ -23,6 +26,8 @@
 #include <cassert>
 #include <cstdlib>
 
+#include "test_macros.h"
+
 namespace ex = std::experimental::pmr;
 
 int count = 0;
@@ -33,7 +38,7 @@ struct destroyable
     ~destroyable() { --count; }
 };
 
-int main()
+int main(int, char**)
 {
     typedef ex::polymorphic_allocator<double> A;
     {
@@ -49,4 +54,6 @@ int main()
         assert(count == 0);
         std::free(ptr);
     }
+
+  return 0;
 }
