@@ -73,6 +73,7 @@ int main(int, char**)
         assert(!is.fail());
         assert(is.gcount() == 3);
     }
+#ifndef TEST_HAS_NO_WIDE_CHARACTERS
     {
         testbuf<wchar_t> sb(L"testing\n...");
         std::wistream is(&sb);
@@ -88,6 +89,7 @@ int main(int, char**)
         assert(!is.fail());
         assert(is.gcount() == 3);
     }
+#endif
 #ifndef TEST_HAS_NO_EXCEPTIONS
     {
         testbuf<char> sb(" ");
@@ -105,6 +107,7 @@ int main(int, char**)
         assert( is.eof());
         assert(!is.fail());
     }
+#ifndef TEST_HAS_NO_WIDE_CHARACTERS
     {
         testbuf<wchar_t> sb(L" ");
         std::basic_istream<wchar_t> is(&sb);
@@ -121,6 +124,7 @@ int main(int, char**)
         assert( is.eof());
         assert(!is.fail());
     }
+#endif
 
     {
         testbuf<char> sb;
@@ -138,6 +142,7 @@ int main(int, char**)
         assert( is.eof());
         assert( is.fail());
     }
+#ifndef TEST_HAS_NO_WIDE_CHARACTERS
     {
         testbuf<wchar_t> sb;
         std::basic_istream<wchar_t> is(&sb);
@@ -155,6 +160,7 @@ int main(int, char**)
         assert( is.fail());
     }
 #endif
+#endif // TEST_HAS_NO_EXCEPTIONS
 
     return 0;
 }
