@@ -33,11 +33,13 @@ int main(int, char**)
         std::istreambuf_iterator<char> i(inf);
         assert(*i++ == 'a');
     }
+#ifndef TEST_HAS_NO_WIDE_CHARACTERS
     {
         std::wistringstream inf(L"abc");
         std::istreambuf_iterator<wchar_t> i(inf);
         assert(*i++ == L'a');
     }
+#endif
 
   return 0;
 }
