@@ -35,10 +35,8 @@ int main(int, char**)
 #if TEST_STD_VER > 17 && defined(__cpp_char8_t)
     test<char8_t, 8>();
 #endif
-#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
     test<char16_t, 16>();
     test<char32_t, 32>();
-#endif // _LIBCPP_HAS_NO_UNICODE_CHARS
     test<short, 15>();
     test<unsigned short, 16>();
     test<int, 31>();
@@ -47,7 +45,7 @@ int main(int, char**)
     test<unsigned long, sizeof(long) == 4 ? 32 : 64>();
     test<long long, 63>();
     test<unsigned long long, 64>();
-#ifndef _LIBCPP_HAS_NO_INT128
+#ifndef TEST_HAS_NO_INT128
     test<__int128_t, 127>();
     test<__uint128_t, 128>();
 #endif
