@@ -11,6 +11,8 @@
 
 // UNSUPPORTED: c++03, c++11, c++14
 
+// XFAIL: LIBCXX-AIX-FIXME
+
 // ::timespec_get is provided by the C library, but it's marked as
 // unavailable until macOS 10.15
 // XFAIL: use_system_cxx_lib && target={{.+}}-apple-macosx10.{{9|10|11|12|13|14}}
@@ -18,5 +20,9 @@
 #include <ctime>
 #include <type_traits>
 
+#ifndef TIME_UTC
+#error TIME_UTC not defined
+#endif
+
 std::timespec tmspec = {};
 static_assert(std::is_same<decltype(std::timespec_get(&tmspec, 0)), int>::value, "");
