@@ -8,7 +8,7 @@
 
 // <string>
 
-// void clear();
+// void clear(); // constexpr since C++20
 
 #include <string>
 #include <cassert>
@@ -17,16 +17,15 @@
 #include "min_allocator.h"
 
 template <class S>
-void
+TEST_CONSTEXPR_CXX20 void
 test(S s)
 {
     s.clear();
     assert(s.size() == 0);
 }
 
-int main(int, char**)
-{
-    {
+TEST_CONSTEXPR_CXX20 bool test() {
+  {
     typedef std::string S;
     S s;
     test(s);
@@ -38,9 +37,9 @@ int main(int, char**)
     s.assign(100, 'a');
     s.erase(50);
     test(s);
-    }
+  }
 #if TEST_STD_VER >= 11
-    {
+  {
     typedef std::basic_string<char, std::char_traits<char>, min_allocator<char>> S;
     S s;
     test(s);
@@ -52,7 +51,17 @@ int main(int, char**)
     s.assign(100, 'a');
     s.erase(50);
     test(s);
-    }
+  }
+#endif
+
+  return true;
+}
+
+int main(int, char**)
+{
+  test();
+#if TEST_STD_VER > 17
+  static_assert(test());
 #endif
 
   return 0;
