@@ -1,16 +1,15 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
 // <string>
 
 // basic_string<charT,traits,Allocator>&
-//   assign(const charT* s, size_type n);
+//   assign(const charT* s, size_type n); // constexpr since C++20
 
 #include <string>
 #include <stdexcept>
@@ -20,7 +19,7 @@
 #include "min_allocator.h"
 
 template <class S>
-void
+TEST_CONSTEXPR_CXX20 void
 test(S s, const typename S::value_type* str, typename S::size_type n, S expected)
 {
     s.assign(str, n);
@@ -28,9 +27,8 @@ test(S s, const typename S::value_type* str, typename S::size_type n, S expected
     assert(s == expected);
 }
 
-int main()
-{
-    {
+TEST_CONSTEXPR_CXX20 bool test() {
+  {
     typedef std::string S;
     test(S(), "", 0, S());
     test(S(), "12345", 3, S("123"));
@@ -48,9 +46,9 @@ int main()
     test(S("12345678901234567890"), "12345", 5, S("12345"));
     test(S("12345678901234567890"), "12345678901234567890", 20,
          S("12345678901234567890"));
-    }
+  }
 #if TEST_STD_VER >= 11
-    {
+  {
     typedef std::basic_string<char, std::char_traits<char>, min_allocator<char>> S;
     test(S(), "", 0, S());
     test(S(), "12345", 3, S("123"));
@@ -68,9 +66,9 @@ int main()
     test(S("12345678901234567890"), "12345", 5, S("12345"));
     test(S("12345678901234567890"), "12345678901234567890", 20,
          S("12345678901234567890"));
-    }
+  }
 #endif
-    { // test assign to self
+  { // test assign to self
     typedef std::string S;
     S s_short = "123/";
     S s_long  = "Lorem ipsum dolor sit amet, consectetur/";
@@ -85,5 +83,17 @@ int main()
 
     s_long.assign(s_long.data() + 2, 8 );
     assert(s_long == "rem ipsu");
-    }
+  }
+
+  return true;
+}
+
+int main(int, char**)
+{
+  test();
+#if TEST_STD_VER > 17
+  static_assert(test());
+#endif
+
+  return 0;
 }
