@@ -1,50 +1,58 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// XFAIL: libcpp-no-exceptions
 // <string>
 
 // basic_string<charT,traits,Allocator>&
-//   replace(size_type pos1, size_type n1, const basic_string<charT,traits,Allocator>& str);
+//   replace(size_type pos1, size_type n1, const basic_string<charT,traits,Allocator>& str); // constexpr since C++20
 
 #include <string>
 #include <stdexcept>
 #include <algorithm>
 #include <cassert>
 
+#include "test_macros.h"
 #include "min_allocator.h"
 
 template <class S>
-void
+TEST_CONSTEXPR_CXX20 void
 test(S s, typename S::size_type pos1, typename S::size_type n1, S str, S expected)
 {
-    typename S::size_type old_size = s.size();
+    const typename S::size_type old_size = s.size();
     S s0 = s;
-    try
+    if (pos1 <= old_size)
     {
         s.replace(pos1, n1, str);
-        assert(s.__invariants());
-        assert(pos1 <= old_size);
+        LIBCPP_ASSERT(s.__invariants());
         assert(s == expected);
         typename S::size_type xlen = std::min(n1, old_size - pos1);
         typename S::size_type rlen = str.size();
         assert(s.size() == old_size - xlen + rlen);
     }
-    catch (std::out_of_range&)
+#ifndef TEST_HAS_NO_EXCEPTIONS
+    else if (!TEST_IS_CONSTANT_EVALUATED)
     {
-        assert(pos1 > old_size);
-        assert(s == s0);
+        try
+        {
+            s.replace(pos1, n1, str);
+            assert(false);
+        }
+        catch (std::out_of_range&)
+        {
+            assert(pos1 > old_size);
+            assert(s == s0);
+        }
     }
+#endif
 }
 
 template <class S>
-void test0()
+TEST_CONSTEXPR_CXX20 bool test0()
 {
     test(S(""), 0, 0, S(""), S(""));
     test(S(""), 0, 0, S("12345"), S("12345"));
@@ -146,10 +154,12 @@ void test0()
     test(S("abcde"), 5, 1, S("12345"), S("abcde12345"));
     test(S("abcde"), 5, 1, S("1234567890"), S("abcde1234567890"));
     test(S("abcde"), 5, 1, S("12345678901234567890"), S("abcde12345678901234567890"));
+
+    return true;
 }
 
 template <class S>
-void test1()
+TEST_CONSTEXPR_CXX20 bool test1()
 {
     test(S("abcde"), 6, 0, S(""), S("can't happen"));
     test(S("abcde"), 6, 0, S("12345"), S("can't happen"));
@@ -251,10 +261,12 @@ void test1()
     test(S("abcdefghij"), 11, 0, S("12345"), S("can't happen"));
     test(S("abcdefghij"), 11, 0, S("1234567890"), S("can't happen"));
     test(S("abcdefghij"), 11, 0, S("12345678901234567890"), S("can't happen"));
+
+    return true;
 }
 
 template <class S>
-void test2()
+TEST_CONSTEXPR_CXX20 bool test2()
 {
     test(S("abcdefghijklmnopqrst"), 0, 0, S(""), S("abcdefghijklmnopqrst"));
     test(S("abcdefghijklmnopqrst"), 0, 0, S("12345"), S("12345abcdefghijklmnopqrst"));
@@ -352,22 +364,38 @@ void test2()
     test(S("abcdefghijklmnopqrst"), 21, 0, S("12345"), S("can't happen"));
     test(S("abcdefghijklmnopqrst"), 21, 0, S("1234567890"), S("can't happen"));
     test(S("abcdefghijklmnopqrst"), 21, 0, S("12345678901234567890"), S("can't happen"));
+
+    return true;
 }
 
-int main()
-{
-    {
-    typedef std::string S;
+template <class S>
+void test() {
+  {
     test0<S>();
     test1<S>();
     test2<S>();
-    }
-#if TEST_STD_VER >= 11
-    {
-    typedef std::basic_string<char, std::char_traits<char>, min_allocator<char>> S;
-    test0<S>();
-    test1<S>();
-    test2<S>();
-    }
+#if TEST_STD_VER > 17
+    static_assert(test0<S>());
+    static_assert(test1<S>());
+    static_assert(test2<S>());
+#endif
+  }
+
+#if TEST_STD_VER > 3
+  { // LWG 2946
+    std::string s = " ";
+    s.replace(0, 1, {"abc", 1});
+    assert(s.size() == 1);
+    assert(s == "a");
+  }
 #endif
 }
+
+int main(int, char**)
+{
+  test<std::string>();
+#if TEST_STD_VER >= 11
+  test<std::basic_string<char, std::char_traits<char>, min_allocator<char>>>();
+#endif
+  return 0;
+}
