@@ -32,9 +32,6 @@
 #include "test_macros.h"
 #include "test_convertible.h"
 
-using std::any;
-using std::any_cast;
-
 template <class Type>
 void test_in_place_type() {
     // constructing from a small type should perform no allocations.
@@ -42,7 +39,7 @@ void test_in_place_type() {
     assert(Type::count == 0);
     Type::reset();
     {
-        any a(std::in_place_type<Type>);
+        std::any a(std::in_place_type<Type>);
 
         assert(Type::count == 1);
         assert(Type::copied == 0);
@@ -52,7 +49,7 @@ void test_in_place_type() {
     assert(Type::count == 0);
     Type::reset();
     { // Test that the in_place argument is properly decayed
-        any a(std::in_place_type<Type&>);
+        std::any a(std::in_place_type<Type&>);
 
         assert(Type::count == 1);
         assert(Type::copied == 0);
@@ -62,7 +59,7 @@ void test_in_place_type() {
     assert(Type::count == 0);
     Type::reset();
     {
-        any a(std::in_place_type<Type>, 101);
+        std::any a(std::in_place_type<Type>, 101);
 
         assert(Type::count == 1);
         assert(Type::copied == 0);
@@ -72,7 +69,7 @@ void test_in_place_type() {
     assert(Type::count == 0);
     Type::reset();
     {
-        any a(std::in_place_type<Type>, -1, 42, -1);
+        std::any a(std::in_place_type<Type>, -1, 42, -1);
 
         assert(Type::count == 1);
         assert(Type::copied == 0);
@@ -88,21 +85,21 @@ void test_in_place_type_tracked() {
     // constructing from a small type should perform no allocations.
     DisableAllocationGuard g(isSmallType<Type>()); ((void)g);
     {
-        any a(std::in_place_type<Type>);
+        std::any a(std::in_place_type<Type>);
         assertArgsMatch<Type>(a);
     }
     {
-        any a(std::in_place_type<Type>, -1, 42, -1);
+        std::any a(std::in_place_type<Type>, -1, 42, -1);
         assertArgsMatch<Type, int, int, int>(a);
     }
     // initializer_list constructor tests
     {
-        any a(std::in_place_type<Type>, {-1, 42, -1});
+        std::any a(std::in_place_type<Type>, {-1, 42, -1});
         assertArgsMatch<Type, std::initializer_list<int>>(a);
     }
     {
         int x = 42;
-        any a(std::in_place_type<Type&>, {-1, 42, -1}, x);
+        std::any a(std::in_place_type<Type&>, {-1, 42, -1}, x);
         assertArgsMatch<Type, std::initializer_list<int>, int&>(a);
     }
 }
@@ -113,24 +110,24 @@ void test_in_place_type_decayed() {
     {
         using Type = decltype(test_func);
         using DecayT = void(*)();
-        any a(std::in_place_type<Type>, test_func);
+        std::any a(std::in_place_type<Type>, test_func);
         assert(containsType<DecayT>(a));
-        assert(any_cast<DecayT>(a) == test_func);
+        assert(std::any_cast<DecayT>(a) == test_func);
     }
     {
         int my_arr[5];
         using Type = int(&)[5];
         using DecayT = int*;
-        any a(std::in_place_type<Type>, my_arr);
+        std::any a(std::in_place_type<Type>, my_arr);
         assert(containsType<DecayT>(a));
-        assert(any_cast<DecayT>(a) == my_arr);
+        assert(std::any_cast<DecayT>(a) == my_arr);
     }
     {
         using Type = int[5];
         using DecayT = int*;
-        any a(std::in_place_type<Type>);
+        std::any a(std::in_place_type<Type>);
         assert(containsType<DecayT>(a));
-        assert(any_cast<DecayT>(a) == nullptr);
+        assert(std::any_cast<DecayT>(a) == nullptr);
     }
 }
 
