@@ -1,21 +1,15 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03, c++11, c++14
+// UNSUPPORTED: c++03, c++11, c++14
 
-// XFAIL: availability=macosx10.13
-// XFAIL: availability=macosx10.12
-// XFAIL: availability=macosx10.11
-// XFAIL: availability=macosx10.10
-// XFAIL: availability=macosx10.9
-// XFAIL: availability=macosx10.8
-// XFAIL: availability=macosx10.7
+// Throwing bad_any_cast is supported starting in macosx10.13
+// XFAIL: use_system_cxx_lib && target={{.+}}-apple-macosx10.{{9|10|11|12}} && !no-exceptions
 
 // <any>
 
@@ -24,21 +18,15 @@
 #include <any>
 #include <cassert>
 
+#include "test_macros.h"
 #include "any_helpers.h"
 
-int main()
+int main(int, char**)
 {
-    using std::any;
-    using std::any_cast;
     // empty
     {
-        any a;
-
-        // noexcept check
-        static_assert(
-            noexcept(a.reset())
-          , "any.reset() must be noexcept"
-          );
+        std::any a;
+        ASSERT_NOEXCEPT(a.reset());
 
         assertEmpty(a);
 
@@ -48,7 +36,7 @@ int main()
     }
     // small object
     {
-        any a((small(1)));
+        std::any a = small(1);
         assert(small::count == 1);
         assertContains<small>(a, 1);
 
@@ -59,7 +47,7 @@ int main()
     }
     // large object
     {
-        any a(large(1));
+        std::any a = large(1);
         assert(large::count == 1);
         assertContains<large>(a, 1);
 
@@ -68,4 +56,6 @@ int main()
         assertEmpty<large>(a);
         assert(large::count == 0);
     }
+
+  return 0;
 }
