@@ -1,13 +1,12 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03, c++11, c++14
+// UNSUPPORTED: c++03, c++11, c++14
 
 // <tuple>
 
@@ -17,6 +16,8 @@
 #include <utility>
 #include <array>
 
+#include "test_macros.h"
+
 template <class Tuple, int Expect>
 void test()
 {
@@ -27,7 +28,7 @@ void test()
     static_assert(std::tuple_size_v<Tuple const volatile> == std::tuple_size<Tuple>::value, "");
 }
 
-int main()
+int main(int, char**)
 {
     test<std::tuple<>, 0>();
 
@@ -40,4 +41,6 @@ int main()
 
     test<std::tuple<int, int, int>, 3>();
     test<std::array<int, 3>, 3>();
+
+  return 0;
 }
